@@ -9,7 +9,7 @@ from .resources.io_manager import qdk_io_manager
 from .s3_connection import S3Connection
 from .training.base import BaseTrainer
 from .training.doc2vec import Doc2VecTrainer
-from .training.mlflow import MLFlowTrainer
+from .training.mlflow import MLFlowTrainingComponent
 from .training.sklearn import SklearnTrainer
 from .training.word2vec import Word2VecTrainer
 from .transform.base import BaseTransformer
